@@ -32,7 +32,7 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkmain.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-volume-monitor.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
@@ -969,7 +969,7 @@ nautilus_path_bar_check_icon_theme (NautilusPathBar *path_bar)
 }
 
 /* Public functions and their helpers */
-static void
+void
 nautilus_path_bar_clear_buttons (NautilusPathBar *path_bar)
 {
         while (path_bar->button_list != NULL) {
@@ -1123,18 +1123,10 @@ button_data_free (ButtonData *button_data)
 static const char *
 get_dir_name (ButtonData *button_data)
 {
-        if (button_data->type == HOME_BUTTON) {
-		if (!desktop_is_home) {
-                	return _("Home");
-		} else {
-			return _("Desktop");
-		}
+        if (button_data->type == DESKTOP_BUTTON || (button_data->type == HOME_BUTTON && desktop_is_home)) {
+		return _("Desktop");
 	} else {
-        	if (button_data->type == DESKTOP_BUTTON) {
-                	return _("Desktop");
-		} else {
-	                return button_data->dir_name;
-		}
+		return button_data->dir_name;
 	}
 }
 
